@@ -169,6 +169,7 @@ _LOGGER = logging.getLogger(__name__)
 
 DEFAULT_BLE_TIMEOUT = 30.0
 DEFAULT_BLE_DISCONNECT_TIMEOUT = 20.0
+DEFAULT_EXECUTE_SERVICE_TIMEOUT = 30.0
 
 SUBSCRIBE_STATES_MSG_TYPES = (*SUBSCRIBE_STATES_RESPONSE_TYPES, CameraImageResponse)
 
@@ -1313,17 +1314,17 @@ class APIClient(APIClientBase):
             UpdateCommandRequest(key=key, command=command, device_id=device_id)
         )
 
-    def execute_service(
+    async def execute_service(
         self,
         service: UserService,
         data: ExecuteServiceDataType,
         *,
-        on_response: Callable[[ExecuteServiceResponseModel], None] | None = None,
-        return_response: bool = False,
-    ) -> None:
+        return_response: bool | None = None,
+        timeout: float = DEFAULT_EXECUTE_SERVICE_TIMEOUT,
+    ) -> ExecuteServiceResponseModel | None:
         connection = self._get_connection()
         # Generate call_id when response callback is provided
-        call_id = next(self._call_id_counter) if on_response is not None else 0
+        call_id = next(self._call_id_counter) if return_response is not None else 0
         req = ExecuteServiceRequest(
             key=service.key,
             call_id=call_id,
@@ -1353,21 +1354,31 @@ class APIClient(APIClientBase):
         req.args.extend(args)
 
         # Register callback for response if provided
-        if on_response is not None:
-            unsub: Callable[[], None] | None = None
+        if return_response is not None:
+            response_event = asyncio.Event()
+            response_msg: ExecuteServiceResponseModel | None = None
 
             def _on_response(msg: ExecuteServiceResponse) -> None:
+                nonlocal response_msg
                 if msg.call_id == call_id:
-                    on_response(ExecuteServiceResponseModel.from_pb(msg))
-                    if unsub is not None:
-                        unsub()
+                    response_msg = ExecuteServiceResponseModel.from_pb(msg)
+                    response_event.set()
 
             unsub = connection.add_message_callback(
                 _on_response,
                 (ExecuteServiceResponse,),
             )
 
-        connection.send_message(req)
+            try:
+                connection.send_message(req)
+                await asyncio.wait_for(response_event.wait(), timeout=timeout)
+                return response_msg
+            finally:
+                unsub()
+        else:
+            connection.send_message(req)
+
+        return None
 
     def _request_image(self, *, single: bool = False, stream: bool = False) -> None:
         self._get_connection().send_message(
